@@ -35,7 +35,7 @@ Usage::
     list_dashboards_paginator: ListDashboardsPaginator = client.get_paginator("list_dashboards")
     list_metrics_paginator: ListMetricsPaginator = client.get_paginator("list_metrics")
 """
-from mypy_boto3_cloudwatch.client import CloudWatchClient as Client, CloudWatchClient
+from mypy_boto3_cloudwatch.client import CloudWatchClient, CloudWatchClient as Client
 from mypy_boto3_cloudwatch.paginator import (
     DescribeAlarmHistoryPaginator,
     DescribeAlarmsPaginator,
@@ -44,8 +44,8 @@ from mypy_boto3_cloudwatch.paginator import (
     ListMetricsPaginator,
 )
 from mypy_boto3_cloudwatch.service_resource import (
-    CloudWatchServiceResource,
     CloudWatchServiceResource as ServiceResource,
+    CloudWatchServiceResource,
 )
 from mypy_boto3_cloudwatch.waiter import AlarmExistsWaiter, CompositeAlarmExistsWaiter
 
